export const selectProvider = '.pf-c-select__menu-item';
export const kebab = 'button.pf-c-dropdown__toggle';
export const kebabDropDownItem = 'li > a.pf-c-dropdown__menu-item';
export const table = '.pf-c-table';
